pub struct FunctionDeclaration {
pub response: Option<Schema>,
pub description: Option<String>,
pub name: String,
pub parameters: Option<Schema>,
}Expand description
Defines a function that the model can generate JSON inputs for.
Fields
response: Option<Schema>Describes the output from the function in the OpenAPI JSON Schema Object format.
description: Option<String>Optional. Description and purpose of the function.
name: StringRequired. The name of the function to call.
parameters: Option<Schema>Optional. Describes the parameters to this function in JSON Schema Object format.
Implementations
Sourceimpl FunctionDeclaration
impl FunctionDeclaration
Sourcepub fn response(self, value: impl Into<Schema>) -> Self
pub fn response(self, value: impl Into<Schema>) -> Self
Sets the response field of this struct.
Sourcepub fn description(self, value: impl Into<String>) -> Self
pub fn description(self, value: impl Into<String>) -> Self
Sets the description field of this struct.
Sourcepub fn parameters(self, value: impl Into<Schema>) -> Self
pub fn parameters(self, value: impl Into<Schema>) -> Self
Sets the parameters field of this struct.