pub struct GoogleSearchRetrieval {
pub dynamic_retrieval_config: Option<DynamicRetrievalConfig>,
}Expand description
Tool to retrieve public web data for grounding, powered by Google.
Fields
dynamic_retrieval_config: Option<DynamicRetrievalConfig>Specifies the dynamic retrieval configuration for the given source.